==> bus-all-3.6.3-sources.jar: org/aoju/bus/spring/oauth/AuthConfiguration.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2017 aoju.org All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.aoju.bus.spring.oauth;

import org.aoju.bus.logger.Logger;
import org.aoju.bus.oauth.cache.DefaultStateCache;
import org.aoju.bus.oauth.cache.StateCache;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;

/**
 * 授权登录相关配置
 *
 * @author Kimi Liu
 * @version 3.6.3
 * @since JDK 1.8
 */
@EnableConfigurationProperties(value = {AuthProperties.class})
public class AuthConfiguration {

    @Bean
    @ConditionalOnProperty(prefix = "request.oauth", value = "enabled", havingValue = "true", matchIfMissing = true)
    public AuthProviderService authRequestFactory(AuthProperties properties, StateCache stateCache) {
        return new AuthProviderService(properties, stateCache);
    }

    /**
     * 默认缓存
     */
    @ConditionalOnMissingBean(StateCache.class)
    @ConditionalOnProperty(name = "request.cache.type", havingValue = "default", matchIfMissing = true)
    static class Default {
        static {
            Logger.debug("使用默认缓存存储 state 数据");
        }

        @Bean
        public StateCache authStateCache() {
            return DefaultStateCache.INSTANCE;
        }
    }

}

==> bus-all-3.6.8-sources.jar: org/aoju/bus/spring/oauth/AuthConfiguration.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2017 aoju.org All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.aoju.bus.spring.oauth;

import org.aoju.bus.oauth.metric.DefaultStateCache;
import org.aoju.bus.oauth.metric.StateCache;
import org.aoju.bus.spring.core.Extend;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;

/**
 * 授权配置
 *
 * @author Kimi Liu
 * @version 3.6.8
 * @since JDK 1.8+
 */
@EnableConfigurationProperties(value = {AuthProperties.class})
public class AuthConfiguration {

    @Bean
    public AuthProviderService authProviderFactory(AuthProperties properties, StateCache stateCache) {
        return new AuthProviderService(properties, stateCache);
    }

    @Bean
    @ConditionalOnMissingBean(StateCache.class)
    @ConditionalOnProperty(name = Extend.OAUTH + ".cache.type", havingValue = "default", matchIfMissing = true)
    public StateCache stateCache() {
        return DefaultStateCache.INSTANCE;
    }

}
